from aspen.http import status_strings

msg = status_strings.get(response.code, 'Sorry')
msg = msg[0].upper() + msg[1:].lower()
if request.website.show_tracebacks:
    err = response.body
else:
    err = ''

<html>
    <head>
        <title>{{ response.code }} {{ msg.title() }}</title>
        <style>
            BODY {
                margin: 0;
                padding: 200px 0 0;
                text-align: center;
                font: normal 18pt/18pt Georgia, serif;
            } 
            PRE {
                text-align: left;
                font: normal 10pt/12pt monospace;
                margin: 50px 200px 0;
            }
        </style>
    </head>
    <body>
        {{ msg }}, program!
        <pre>{{ err }}</pre>
    </body>
</html>
